#!/bin/bash
set -u
set -e

# Usage:
# ./run_tests.sh 2>&1 | tee log.run_tests.txt

THISSCRIPT=${0##*/}
VERSION=1.2.2

function bail () { echo -e "\nError: ${1:-Unknown Error}"; exit ${2:-1}; }

H="=============================================================================="

TEST_HOME=${TEST_HOME:-Undefined}

if [[ $TEST_HOME == Undefined ]]; then
   cd .. || bail
   source ./env.sh || bail "Error finding or loading shell environment file."
fi

[[ $P4ROOT != $TEST_HOME/.p4root ]] && bail "Invalid P4ROOT [$P4ROOT]."

echo "Resetting P4ROOT."
/bin/rm -rf "$P4ROOT"
/bin/mkdir "$P4ROOT"

echo -e "Triggers:\n\tJobName form-in job \"$APP_HOME/src/job-new.sh %formfile%\"\n\n" | p4 triggers -i

scriptVer=$(grep VERSION= $TEST_HOME/../src/job-new.sh|cut -d '=' -f 2)
echo -e "$THISSCRIPT v$VERSION testing job-new.sh v$scriptVer\n$(ls -l $TEST_HOME/../src/job-new.sh)\n"
echo TEST_HOME=$TEST_HOME
export P4CONFIG=${P4CONFIG:-Undefined}
[[ "$P4CONFIG" != *.p4config.test ]] && bail "Bad P4CONFIG setting."

echo "Test Environment Info:"
for p4Cmd in "set" "-s info -s" "login -s" "triggers -o"; do
   p4 $p4Cmd ||:
done

echo Remove any jobs from the test server.
for job in $(p4 -ztag -F %Job% jobs); do
   p4 job -d $job ||:
done

echo "Running 9 tests (Pass 1)"
for f in 1 2 3 4 5 6 7 8 9; do
   testFile=$TEST_DATA/test-$f.job
   job=$(grep ^Job: $testFile ||:)
   job=${job#Job:}
   job=$(echo $job)
   echo -e "\n${H}\nProcessing test file [$testFile] with job [$job]."
   cp -p -f $testFile foo.txt ||:
   #$TEST_HOME/../src/job-new.sh foo.txt
   cat foo.txt
   p4 job -i < foo.txt ||:
done

echo "Running 5 tests (Pass 2)"
for f in 3 4 5 6 7; do
   testFile=$TEST_DATA/test-$f.job
   job=$(grep ^Job: $testFile ||:)
   job=${job#Job:}
   job=$(echo $job)
   echo -e "${H}\nRe-Processing test file [$testFile] with job [$job]."
   cp -p -f $testFile foo.txt ||:
   #$TEST_HOME/../src/job-new.sh foo.txt
   cat foo.txt
   p4 job -i < foo.txt ||:
done

echo "Running 3 tests (Pass 3)"
for f in 5 6 7; do
   testFile=$TEST_DATA/test-$f.job
   job=$(grep ^Job: $testFile ||:)
   job=${job#Job:}
   job=$(echo $job)
   echo -e "${H}\nRe-Re-Processing test file [$testFile] with job [$job]."
   cp -p -f $testFile foo.txt ||:
   #$TEST_HOME/../src/job-new.sh foo.txt
   cat foo.txt
   p4 job -i < foo.txt ||:
done

/bin/rm -f foo.txt
